@@ -14,9 +14,13 @@ test_that("variable classes are preserved", {
   rownames(ab2) <- NULL
 
   expect_that(ab1, equals(ab2))
-  expect_that(unname(lapply(ab1, class)),
-    equals(list("factor", "integer", "factor", "Date", c("POSIXct", "POSIXt"),
-                "matrix")))
+
+  expect_s3_class(ab1$a, "factor")
+  expect_type(ab1$b, "integer")
+  expect_s3_class(ab1$c, "factor")
+  expect_s3_class(ab1$d, "Date")
+  expect_s3_class(ab1$e, "POSIXct")
+  expect_equal(dim(ab1$f), c(6, 2))
 })
 
 test_that("same as rbind for simple cases", {
@@ -79,9 +83,12 @@ test_that("character or factor or list-matrices are preserved", {
 
 test_that("missing levels in factors preserved", {
   f <- addNA(factor(c("a", "b", NA)))
-  df1 <- data.frame(a = f)
-  df2 <- data.frame(b = f)
-  rbind.fill(df1, df2)
+  df1 <- data.frame(a = f, c = f)
+  df2 <- data.frame(b = f, c = f)
+  out <- rbind.fill(df1, df2)
+  expect_equal(levels(out$a), levels(f))
+  expect_equal(levels(out$b), levels(f))
+  expect_equal(levels(out$c), levels(f))
 })
 
 test_that("time zones are preserved", {
@@ -114,7 +121,7 @@ test_that("1d arrays treated as vectors", {
   df <- data.frame(x = 1)
   df$x <- array(2, 1, list(x="one"))
   df2 <- rbind.fill(df, df)
-  expect_that(is.null(dimnames(df2$x)), is_true())
+  expect_null(dimnames(df2$x))
 
   #can bind 1d array to vector
   dfV <- data.frame(x=3)
@@ -279,7 +286,7 @@ expect_linear_enough <- function(timings, threshold=0.1) {
   #expect that no more than `threshold` of a `size` input's runtime is
   #accounted for by quadratic behavior
   model <- lm(I(user.self / size) ~ size, timings)
-  expect_less_than(threshold, summary(model)$coefficients[2,4])
+  expect_lt(threshold, summary(model)$coefficients[2,4])
 }
 
 test_that("rbind.fill performance linear", {
